DedicatedVirtualAccountClient class
It provides methods that mirror endpoints provided by Paystack's Dedicated Virtual Account API which enables Nigerian merchants to manage unique payment accounts of their customers.
- Inheritance
-
- Object
- BaseClient
- DedicatedVirtualAccountClient
Constructors
- DedicatedVirtualAccountClient({String? secretKey})
- Create an instance of DedicatedVirtualAccountClient.
Properties
- baseUrl → String
-
no setterinherited
- client ↔ Client
-
getter/setter pairinherited
- dataAsListKey → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
all(
bool active, {Currency currency = Currency.ngn, String? providerSlug, String? bankId, String? customer}) → Future< Response> - Retrieve all the dedicated virtual accounts available on your integration.
-
assign(
String email, String firstName, String lastName, String phone, String preferredBank, {Country country = Country.nigeria, String? accountNumber, String? bvn, String? bankCode, String? subaccount, List< String> ? splitCode}) → Future<Response> - Create a customer, validate the customer, and assign a DVA to the customer.
-
bankProviders(
) → Future< Response> - Retrieve bank providers for a dedicated virtual account.
-
call(
Uri url, HttpMethod method, {NativeJsonData? data, bool dataAsList = false}) → Future< Response> -
inherited
-
create(
String customer, {String? preferredBank, String? subaccount, String? splitCode, String? firstName, String? lastName, String? phone}) → Future< Response> - Create a dedicated virtual account for an existing customer.
-
deactivate(
String dedicatedAccountId) → Future< Response> - Deactivate a dedicated virtual account on your integration.
-
fetchOne(
String dedicatedAccountId) → Future< Response> - Retrieve a single dedicated virtual account available on your integration by it's id.
-
normalizeQueryParameters(
Map< String, dynamic> queryParameters) → Map<String, dynamic> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeSplit(
String accountNumber) → Future< Response> - If you've previously set up split payment for transactions on a dedicated virtual account, you can remove it with this method.
-
requery(
String accountNumber, String providerSlug, {String? date}) → Future< Response> - Requery a dedicated virtual account for new transactions.
-
splitTransaction(
String customer, {String? subaccount, String? splitCode, String? preferredBank}) → Future< Response> - Split a dedicated virtual account transaction with one or more accounts
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited